==> ignition-plugin_1.3.0.orig.tar.bz2: ignition-plugin-1.3.0/Changelog.md <==
## Gazebo Plugin 1.x

### Gazebo Plugin 1.3.0 (2022-08-15)

1. Remove redundant namespace references
    * [Pull request #100](https://github.com/gazebosim/gz-plugin/pull/100)

1. Change `IGN_DESIGNATION` to `GZ_DESIGNATION`
    * [Pull request #96](https://github.com/gazebosim/gz-plugin/pull/96)

1. Ignition -> Gazebo
    * [Pull request #94](https://github.com/gazebosim/gz-plugin/pull/94)

1. Bash completion for flags
    * [Pull request #81](https://github.com/gazebosim/gz-plugin/pull/81)

1. Add LICENSE file
    * [Pull request #72](https://github.com/gazebosim/gz-plugin/pull/72)

1. Add Ubuntu Jammy CI
    * [Pull request #68](https://github.com/gazebosim/gz-plugin/pull/68)

1. Install ruby commands on Windows
    * [Pull request #63](https://github.com/gazebosim/gz-plugin/pull/63)

### Ignition Plugin 1.2.1 (2021-09-24)

1. Add Doxygen documentation checks to CI
    * [Pull request #59](https://github.com/ignitionrobotics/ign-plugin/pull/59)

1. Infrastructure
    * [Pull request #58](https://github.com/ignitionrobotics/ign-plugin/pull/58)
    * [Pull request #52](https://github.com/ignitionrobotics/ign-plugin/pull/52)
    * [Pull request #51](https://github.com/ignitionrobotics/ign-plugin/pull/51)

1. Find ign program instead of ignition-tools
    * [Pull request #57](https://github.com/ignitionrobotics/ign-plugin/pull/57)

1. Remove ign-tools from CMakeLists.txt. Not used
    * [Pull request #56](https://github.com/ignitionrobotics/ign-plugin/pull/56)

### Ignition Plugin 1.2.0 (2021-03-30)

1. Infrastructure
    * [Pull request #45](https://github.com/ignitionrobotics/ign-plugin/pull/45)
    * [Pull request #44](https://github.com/ignitionrobotics/ign-plugin/pull/44)
    * [Pull request #43](https://github.com/ignitionrobotics/ign-plugin/pull/43)
    * [Pull request #36](https://github.com/ignitionrobotics/ign-plugin/pull/36)
    * [Pull request #28](https://github.com/ignitionrobotics/ign-plugin/pull/28)
    * [Pull request #26](https://github.com/ignitionrobotics/ign-plugin/pull/26)
    * [Pull request #15](https://github.com/ignitionrobotics/ign-plugin/pull/15)
    * [Pull request #10](https://github.com/ignitionrobotics/ign-plugin/pull/10)
    * [Pull request #14](https://github.com/ignitionrobotics/ign-plugin/pull/14)
    * [Pull request #8](https://github.com/ignitionrobotics/ign-plugin/pull/8)
    * [Pull request #47](https://github.com/ignitionrobotics/ign-plugin/pull/47)

1. Include windows instructions in examples README.md and fix examples to compile them on Windows
    * [Pull request #48](https://github.com/ignitionrobotics/ign-plugin/pull/48)

1. Fix downstream Windows builds
    * [Pull request #38](https://github.com/ignitionrobotics/ign-plugin/pull/38)

1. Add `ign plugin --info` to print plugin info
    * [Pull request #32](https://github.com/ignitionrobotics/ign-plugin/pull/32)

1. Add Windows installation
    * [Pull request #34](https://github.com/ignitionrobotics/ign-plugin/pull/34)

1. Add plugin name accessor
    * [Pull request #29](https://github.com/ignitionrobotics/ign-plugin/pull/29)

### Ignition Plugin 1.1.0 (2019-11-21)

1. Add SelectSpecializers to allow ign-physics to improve compilation time.
    * [BitBucket pull request 32](https://osrf-migration.github.io/ignition-gh-pages/#!/ignitionrobotics/ign-physics/pull-requests/32)

### Ignition Plugin 1.0.0 (2019-02-05)

1. Initial release

==> ignition-plugin_1.4.0.orig.tar.bz2: ignition-plugin-1.4.0/Changelog.md <==
## Gazebo Plugin 1.x

### Gazebo Plugin 1.3.0 (2022-11-11)

1. ign -> gz Migrate Ignition Headers : gz-plugin
    * [Pull request #101](https://github.com/gazebosim/gz-plugin/pull/101)

### Gazebo Plugin 1.3.0 (2022-08-15)

1. Remove redundant namespace references
    * [Pull request #100](https://github.com/gazebosim/gz-plugin/pull/100)

1. Change `IGN_DESIGNATION` to `GZ_DESIGNATION`
    * [Pull request #96](https://github.com/gazebosim/gz-plugin/pull/96)

1. Ignition -> Gazebo
    * [Pull request #94](https://github.com/gazebosim/gz-plugin/pull/94)

1. Bash completion for flags
    * [Pull request #81](https://github.com/gazebosim/gz-plugin/pull/81)

1. Add LICENSE file
    * [Pull request #72](https://github.com/gazebosim/gz-plugin/pull/72)

1. Add Ubuntu Jammy CI
    * [Pull request #68](https://github.com/gazebosim/gz-plugin/pull/68)

1. Install ruby commands on Windows
    * [Pull request #63](https://github.com/gazebosim/gz-plugin/pull/63)

### Ignition Plugin 1.2.1 (2021-09-24)

1. Add Doxygen documentation checks to CI
    * [Pull request #59](https://github.com/ignitionrobotics/ign-plugin/pull/59)

1. Infrastructure
    * [Pull request #58](https://github.com/ignitionrobotics/ign-plugin/pull/58)
    * [Pull request #52](https://github.com/ignitionrobotics/ign-plugin/pull/52)
    * [Pull request #51](https://github.com/ignitionrobotics/ign-plugin/pull/51)

1. Find ign program instead of ignition-tools
    * [Pull request #57](https://github.com/ignitionrobotics/ign-plugin/pull/57)

1. Remove ign-tools from CMakeLists.txt. Not used
    * [Pull request #56](https://github.com/ignitionrobotics/ign-plugin/pull/56)

### Ignition Plugin 1.2.0 (2021-03-30)

1. Infrastructure
    * [Pull request #45](https://github.com/ignitionrobotics/ign-plugin/pull/45)
    * [Pull request #44](https://github.com/ignitionrobotics/ign-plugin/pull/44)
    * [Pull request #43](https://github.com/ignitionrobotics/ign-plugin/pull/43)
    * [Pull request #36](https://github.com/ignitionrobotics/ign-plugin/pull/36)
    * [Pull request #28](https://github.com/ignitionrobotics/ign-plugin/pull/28)
    * [Pull request #26](https://github.com/ignitionrobotics/ign-plugin/pull/26)
    * [Pull request #15](https://github.com/ignitionrobotics/ign-plugin/pull/15)
    * [Pull request #10](https://github.com/ignitionrobotics/ign-plugin/pull/10)
    * [Pull request #14](https://github.com/ignitionrobotics/ign-plugin/pull/14)
    * [Pull request #8](https://github.com/ignitionrobotics/ign-plugin/pull/8)
    * [Pull request #47](https://github.com/ignitionrobotics/ign-plugin/pull/47)

1. Include windows instructions in examples README.md and fix examples to compile them on Windows
    * [Pull request #48](https://github.com/ignitionrobotics/ign-plugin/pull/48)

1. Fix downstream Windows builds
    * [Pull request #38](https://github.com/ignitionrobotics/ign-plugin/pull/38)

1. Add `ign plugin --info` to print plugin info
    * [Pull request #32](https://github.com/ignitionrobotics/ign-plugin/pull/32)

1. Add Windows installation
    * [Pull request #34](https://github.com/ignitionrobotics/ign-plugin/pull/34)

1. Add plugin name accessor
    * [Pull request #29](https://github.com/ignitionrobotics/ign-plugin/pull/29)

### Ignition Plugin 1.1.0 (2019-11-21)

1. Add SelectSpecializers to allow ign-physics to improve compilation time.
    * [BitBucket pull request 32](https://osrf-migration.github.io/ignition-gh-pages/#!/ignitionrobotics/ign-physics/pull-requests/32)

### Ignition Plugin 1.0.0 (2019-02-05)

1. Initial release
